# Git record

Use git branch to record temporal code.


## Install

`python setup.py install` or `pip install -e .`


## Usage

``` python
from git_record.git_record import GitHandle

gh = GitHandle()
gh.create_new_branch()

```

This scripts will create a branch named `current date`.


## ..MORE?

1. Folk this repo.
2. `pip install -e .`
3. run `python example/ex1.py`